==> libreoffice-6.1.1.2.tar.xz: libreoffice-6.1.1.2/comphelper/source/misc/comphelper_module.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include <comphelper_module.hxx>


namespace comphelper { namespace module
{


    struct ComphelperModuleCreator
    {
        ComphelperModule m_aComphelperModule;
    };
    namespace
    {
        class theComphelperModuleInstance : public rtl::Static<ComphelperModuleCreator, theComphelperModuleInstance> {};
    }

    ComphelperModule::ComphelperModule()
        :BaseClass()
    {
    }

    ComphelperModule& ComphelperModule::getInstance()
    {
        return theComphelperModuleInstance::get().m_aComphelperModule;
    }


} } // namespace comphelper::module


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.0.4.orig.tar.xz: libreoffice-7.0.4.2/comphelper/source/misc/comphelper_module.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */


#include <comphelper_module.hxx>


namespace comphelper::module
{


    struct ComphelperModuleCreator
    {
        ComphelperModule m_aComphelperModule;
    };
    namespace
    {
        class theComphelperModuleInstance : public rtl::Static<ComphelperModuleCreator, theComphelperModuleInstance> {};
    }

    ComphelperModule::ComphelperModule()
        :BaseClass()
    {
    }

    ComphelperModule& ComphelperModule::getInstance()
    {
        return theComphelperModuleInstance::get().m_aComphelperModule;
    }


} // namespace comphelper::module


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
